#!/bin/sh

# Micromuse Netcool/Reporter Apache for Unix Installation Script
# Copyright (c)2005 Micromuse Ltd. All Rights Reserved


###########
SubInit() {
###########
  REQDISKSPC=350000

  NRCLEAR=${NRCLEAR:-/usr/bin/clear}

  if [ `echo "x\c"` = "x" ]
  then
    gEchoNL=SubEchoC
  else
    gEchoNL=SubEchoN
  fi
}


##########
f_Spin() {
##########
   if [ -z "$STATE" ]; then
      $gEchoNL "[|]"
      STATE=1
      return
   fi

   if [ -n "$1" ]; then
      $gEchoNL "\b\b\b[$1]"
      STATE=`expr $STATE + 1`
      STATE=`expr $STATE % 8`
   fi
   
   case $STATE in
      0 ) $gEchoNL "\b\b\b[|]"
          STATE=1 ;;
      1 ) $gEchoNL "\b\b\b[/]" 
          STATE=2 ;;
      2 ) $gEchoNL "\b\b\b[-]" 
          STATE=3 ;;
      3 ) $gEchoNL "\b\b\b[\\]" 
          STATE=4 ;;
      4 ) $gEchoNL "\b\b\b[|]"
          STATE=5 ;;
      5 ) $gEchoNL "\b\b\b[/]"
          STATE=6 ;;
      6 ) $gEchoNL "\b\b\b[-]"
          STATE=7 ;;
      7 ) $gEchoNL "\b\b\b[\\]"
          STATE=0 ;;
   esac
}


###########
f_GetOS() {
###########
   ARCH=""
   OS=""

   if [ `uname -s` = SunOS ]; then
      ARCH="solaris"      # Solaris on Sparc
      if [ `uname -r` = "5.6" ]; then
         OS="2"      # solaris 2.6
      elif [ `uname -r` = "5.7" ]; then
         OS="7"      # solaris 2.7
      elif [ `uname -r` = "5.8" ]; then
         OS="8"      # solaris 2.8
      elif [ `uname -r` = "5.9" ]; then
         OS="9"      # solaris 2.9
      else
         echo "Unsupported version of Solaris"
         exit 1
      fi   
   fi
   
   if [ `uname -s` = HP-UX ]; then
      ARCH="hpux"      # HP-UX 
      if [ `uname -r | sed  -e 's/..\(..\).*/\1/'` = 11 ]; then
         OS="11"   # HP-UX 11
      else
         echo "Unsupported version of HP-UX"
         exit 1
      fi
   fi

	if [ `uname -s` = Linux ]; then
      ARCH="linux"      # Linux
      if [ `uname -r | sed -e 's/\(^[0-9]*\.[0-9]*\).*/\1/g'` = "2.4" ]; then
	if [ `uname -r | sed -e 's/^[0-9]*\.[0-9]*\.\([0-9]*\)\-.*/\1/g'` -ge "9" ]; then
	  OS="9"   # Linux 9 Kernal
	fi
     fi
      if [ `uname -r | sed -e 's/\(^[0-9]*\.[0-9]*\).*/\1/g'` = "2.6" ]; then
	if [ `uname -r | sed -e 's/^[0-9]*\.[0-9]*\.\([0-9]*\)\-.*/\1/g'` -ge "9" ]; then
	  OS="9"   # Linux 9 Kernal
	fi
     fi
   fi

   if [ `uname -s` = AIX ]; then
      ARCH="aix"      # AIX 
      OS=
      if [ `uname -v` -eq 4 ]; then   # AIX 4
         if [ `uname -r` -eq 3 ]; then
            OS="43"      # AIX 4.3
         fi
       elif [ `uname -v` -eq 5 ]; then   # AIX 5
         if [ `uname -r` -eq 0 -o `uname -r` -eq 1 -o `uname -r` -eq 2 -o `uname -r` -eq 3 ]; then
            OS="5L"      # AIX 5.0 or 5.1 or 5.2 or 5.3
         fi
      fi

      if [ -z "$OS" ]; then
         echo "Unsupported version of Operating System."
         exit 1
      fi
   fi

   if [ -z "$ARCH" -o -z "$OS" ]; then
      echo "Unsupported Architecture or Operating System."
      exit 1
   fi
}

##############
f_Replace () {
##############
   if [ ! -f "$1" ]; then
      $gEchoNL "File...\n\n\t$1\n\n...does not exist"
      return
   fi

   RES=`cat $1 | sed -e "s#$2#$3#g" > /tmp/$$.tmp 2>&1`
   if [ $? -gt 0 ]; then
      echo "Failed to search and replace text string $2 in $1"
      echo "$RES"

      RES=`rm /tmp/$$.tmp 2>&1`
      exit 1
   fi

   RES=`cp /tmp/$$.tmp $1 2>&1`
   if [ $? -gt 0 ]; then
      echo "Failed to search and replace text string $2 $1"
      echo "$RES"

      RES=`rm /tmp/$$.tmp 2>&1`
      exit 2
   fi

   RES=`rm /tmp/$$.tmp 2>&1`
}

###########
f_Title() {
###########
   $NRCLEAR

   if [ "$ARCH" = "aix" ]; then
      echo '======================================================='
      echo 'Welcome to Netcool/Reporter Apache Installation for AIX'
      echo '======================================================='
   elif [ "$ARCH" = "hpux" ]; then
      echo '========================================================='
      echo 'Welcome to Netcool/Reporter Apache Installation for HP-UX'
      echo '========================================================='
   elif [ "$ARCH" = "linux" ]; then
      echo '========================================================='
      echo 'Welcome to Netcool/Reporter Apache Installation for Linux'
      echo '========================================================='
   else
      echo '================================================================='
      echo 'Welcome to Netcool/Reporter Apache Installation for Solaris Sparc'
      echo '================================================================='
   fi

   if [ $# -eq 1 ]; then
	   echo ''
	   echo "$1"
	   CC=`echo $1 | wc -m`
	   I=1
	   LINE=
	   while [ $I -lt $CC ]; do
		   LINE="-$LINE"
		   I=`expr $I + 1`
	   done
	   echo $LINE
   fi

   echo ' '
}

###########
f_IsNum() {
###########
   NUM=`echo $1 | grep "^[0-9]*$"`
   if [ -z "$NUM" ]; then
      return 1
   else
      return 0
   fi
}


###########
f_Pause() {
###########
   echo ' '
   $gEchoNL "Press <Return> or <Enter> when ready...\c"
   read key
}


####################
f_GetPorts() {
####################
   echo ''
   $gEchoNL 'Generating list of ports in use... '
   if [ "$ARCH" = "solaris" ]; then
      gACTIVPORTS=`netstat | grep "^.*\.[0-9]* *" | awk '{print $1}' | grep ".*[0-9]$"`
   else
      gACTIVPORTS=`netstat | awk '{print $4}' | grep "^[a-z|A-Z].*[0-9]$"`    
   fi

   gREGPORTS=`cat /etc/services | awk '{print $2}' | grep "^[0-9]*/"` 
  
   echo ''
   echo 'Completed.'
}


##############
f_FreePort() {
##############
   f_IsNum $1
   if [ $? -eq 1 ]; then
      echo 'ERROR: The port you entered must only be a numeric value.'
      return 1
   fi
  
   echo "Validating port - $1"
   f_Spin

   PORTUSED=0
   for i in $gACTIVPORTS; do
      USED=`echo $i | grep "\.${1}$"`
      if [ -n "$USED" ]; then    
         PORTUSED=1
         break
      fi
      f_Spin
   done

   if [ $PORTUSED -eq 1 ]; then
      echo ' '
      echo "ERROR: The port you entered is currently in use."
      f_GetPorts
      return 2
   fi

   PORTREG=0
   for i in $gREGPORTS; do
      REG=`echo $i | grep "^$1/"`
      if [ -n "$REG" ]; then
         PORTREG=1
         break
      fi
      f_Spin
   done

   $gEchoNL "\b\b\bCompleted."
   echo ' '

   if [ $PORTREG -eq 1 ]; then
      echo ' '
      echo "WARNING: The port you entered is already defined in /etc/services."
      echo ' '
      SubYesNo "Do you wish to use port $1 anyway (y/n)? [n] " 1
      if [ $? -eq 0 ]; then
         echo ' '
         return 0
      else
         echo ' '
         return 3
      fi
   fi

   if [ -n "$2" ]; then
   	for i in $2; do
      	if [ $i -eq $1 ]; then
		echo ' '
         	echo "ERROR: The port you entered has already been designated for use."
         	return 4
      	fi
   	done
   fi

   return 0
}


#####################
f_VarifyDiskSpace() {
#####################
   gFreeSpace=0
   if [ ! -d $1 ]; then
	   return 2
   fi

   SPACE=`df -k $1`
   
   if [ $ARCH = "hpux" ]; then
      gFreeSpace=`echo $SPACE | awk '{print $9}'`
   else
      gFreeSpace=`echo $SPACE | awk '{print $11}'`
   fi

   if [ -z "$gFreeSpace" ]; then
      return 0
   fi
   
   if [ $gFreeSpace -lt $REQDISKSPC ]; then
      return 1
   fi
   
   return 0
}


############
SubAbort() {
############   
   echo ' '
   echo '*** Installation aborted ***'
   echo 'To redo the Installation, please launch the setup script again.'
   echo ' '
   exit 1
}


############
SubEchoC() {
############
   echo "${*}\c"
}


############
SubEchoN() {
############
   echo "$*"
}


############
SubYesNo() {
############
   while true
   do
      $gEchoNL "$1"
      read answer

      if [ "$answer" ]
      then
         case "$answer" in
            y|Y|yes|YES|Yes)
               return 0
               ;;
            n|N|no|NO|No)
               return 1
               ;;
            *)
               echo ' '
               echo 'ERROR: Invalid response, expected "yes" or "no".'
               continue
               ;;
         esac
      else
         return "$2"
      fi
   done
}


###################
SubYesNoLiteral() {
###################
   while true
   do
      echo ' '
      $gEchoNL "$1"
      read answer

      case "$answer" in
         yes|YES|Yes)
            return 0
            ;;
         no|NO|No)
            return 1
            ;;
         *)
            echo ' '
            echo 'ERROR: Invalid response, expected "yes" or "no".'
            continue
            ;;
      esac
   done
}


########################
SubContinueBackAbort() {
########################
   while true
   do
      echo ' '
      $gEchoNL "$1"
      read answer

      if [ "$answer" ]
      then
         case "$answer" in
            c|C|continue|CONTINUE|Continue)
               return 0
               ;;
            b|B|back|BACK|Back)
               return 1
               ;;
            a|A|abort|ABORT|Abort)
               SubAbort
               ;;
            *)
               echo ' '
               echo 'ERROR: Invalid response, expected "c" or "b" or "a"'
               echo '       or "continue" or "back" or "abort".'
               continue
               ;;
         esac
      else
         return "$2"
      fi
   done
}


################
SubBackAbort() {
################   
   while true
   do
      echo ' '
      $gEchoNL "$1"
      read answer

      if [ "$answer" ]
      then
         case "$answer" in
            b|B|back|BACK|Back)
               return 0
               ;;
            a|A|abort|ABORT|Abort)
               SubAbort
               ;;
            *)
               echo ' '
               echo 'ERROR: Invalid response, expected "b" or "a"'
               echo '       or "back" or "abort".'
               continue
               ;;
          esac
      else
          return "$2"
      fi
   done
}


####################
SubContinueAbort() {
####################
   while true
   do
      echo ' '
      $gEchoNL "$1"
      read answer

      if [ "$answer" ]
      then
         case "$answer" in
            c|C|continue|CONTINUE|Continue)
               return 0
               ;;
            a|A|abort|ABORT|Abort)
               SubAbort
               ;;
           *)
             echo ' '
             echo 'ERROR: Invalid response, expected "c" or "a"'
             echo '       or "continue" or "abort".'
             continue
             ;;
         esac
      else
         return "$2"
      fi
   done
}


###############
SubOneOrTwo() {
###############
  while true
  do
    echo ' '
    $gEchoNL "$1"
    read answer

    if [ "$answer" ]
    then
      case "$answer" in
        1|one)
          return 0
          ;;
        2|two)
          return 1
          ;;
        *)
          continue
          ;;
      esac
    else
      return "$2"
    fi
  done
}


###############
SubOneToSix() {
###############
    echo ' '
    $gEchoNL "$1"
}


############
SubEnter() {
############
  read answer
  if [ "$answer" ]
  then
    eval "$2"="$answer"
  else
    eval "$2"="$1"
  fi

  echo ' '
}


#################
SubPathConcat() {
#################
  endsInSlash=`expr X"$1" : '.*/$'`
  if [ "$endsInSlash" != '0' ]
  then
    eval "$3"="$1""$2"
  else
    eval "$3"="$1"'/'"$2"
  fi
}


################################################################################
# End Of Utility Functions
################################################################################


################################################################################
# Start Of Installation Functions
################################################################################


#
# Called from SubMain()
#


#
# Operation - 20
#
##########################
SubReporterDestination() {
##########################
	f_Title 'APACHE 1.3.37 FOR REPORTER INSTALL LOCATION'

	if [ -n "$gReporterInstallLocation" ]; then
		repinstallloc=$gReporterInstallLocation
  	else
		repinstallloc=/export/opt/netcool/reporter/reporter2.0
  	fi
	
	echo 'Enter the physical path to where you wish Apache 1.3.37 to be installed under.'
	echo 'PLEASE NOTE: The subdirectory "apache" will automatically be created under the'
	echo 'directory your specify.'
	echo ''
  	$gEchoNL 'Default value is "'$repinstallloc'": '
  	SubEnter "$repinstallloc" 'gReporterInstallLocation'
  
  	if [ -d "$gReporterInstallLocation" ]
  	then
	    gScreen=40
  	else
    		echo ' '
    		echo 'WARNING: '"$gReporterInstallLocation"' does not exist.'
    		echo 'Do you want to create this directory or go back and make changes?'
    		echo ' '

    		if SubContinueBackAbort '(C)reate, go (B)ack to make changes, or (A)bort (c/b/a)? [c] ' 0
    		then
      			mkdir -p $gReporterInstallLocation
      			if [ -d $gReporterInstallLocation ]
      			then
        			gScreen=40
				echo ' '
			else
        			echo ' '
        			echo 'ERROR: '"$gReporterInstallLocation"' could not be created.'
        			echo 'Please go back and make changes.'
        			echo ' '
				f_Pause
        			gScreen=20
				return
      			fi
		else
      			gScreen=20
			return
  		fi
	fi

	f_VarifyDiskSpace $gReporterInstallLocation
	RET=$?
	if [ $RET -eq 1 ]; then
		rmdir $gReporterInstallLocation
		echo 'You do not have enougth diskspace to install Apache 1.3.37 for Reporter 2.0 under:'
		$gEchoNL "\t$gReporterInstallLocation"
		echo ' '
		echo 'The current free diskspace you have under that directory location is'
		$gEchoNL "\t${gFreeSpace}Kb."
		echo ' '
		echo 'WARNING: If you continue you may have future issues.'
  		SubContinueBackAbort '(C)ontinue, go (B)ack to make changes, or (A)bort (c/b/a)? [b] ' 1
		if [ $? -eq 1 ]
	  	then
			gScreen=20
			return
		fi

		echo ' '
  	elif [ $RET -eq 2 ]; then
  		echo 'The directory specified is invalid or does not exist:'
		$gEchoNL "\t$gReporterInstallLocation"
		f_Pause
		gScreen=20
		return
	fi

	f_Title 'APACHE 1.3.37 FOR REPORTER INSTALL LOCATION'

  	echo 'Summary for the Apache 1.3.37 Install:'
	echo ' '
	echo '  Physical root install path for Apache 1.3.37 is:'
	echo "    "$gReporterInstallLocation"/apache"
	echo ' '

  	if SubContinueBackAbort '(C)ontinue, go (B)ack to make changes, or (A)bort (c/b/a)? [c] ' 0
  	then
		gScreen=10
	else
		gScreen=20
	fi
}


#
# Operation - 10
#
########################
SubSuppliedWebServer() {
########################
  f_Title 'APACHE WEB SERVER CONFIGURATION'

  if [ "$gHostName" ]
  then
    hostname=$gHostName
  elif [ `domainname` ] && [ `domainname` != "(none)" ]
  then
    hostname="`hostname`.`domainname`"
  else
    hostname=`hostname`
  fi
   
  echo 'Enter the hostname of your web server (Example: www.myserver.com)'
  $gEchoNL 'Default value is "'$hostname'": '
  SubEnter "$hostname" 'gHostName'

  if SubYesNo 'Would you like to use HTTPS protocol for the Reporter server (y/n)? [n] ' 1
 then
    bSSL=1
  else
    bSSL=0
  fi
  
  if [ "$gPortNum" ]
  then
    if [ $bSSL -eq 1 -a $gPortNum -eq 80 ]; then
        port=443
    elif [ $bSSL -eq 0 -a $gPortNum -eq 443 ]; then
        port=80
    else
        port=$gPortNum
    fi
  else
    if [ $bSSL -eq 1 ]; then
	    port='443'
    else
	    port='80'
    fi
  fi

  echo ' '

  cont=0
  while [ $cont -eq 0 ]
  do
    echo 'Enter the http port number of your Web Server (Example: 8080)'
    echo "Please use the default value unless you are confident to use a different value."
    $gEchoNL 'Default value is "'$port'": '

    SubEnter "$port" 'gPortNum'

    f_FreePort $gPortNum
    if [ $? -gt 0 ]; then
          gPortNum=$port
	  f_Pause
	  f_Title 'WEB SERVER CONFIGURATION'
    else
	cont=1
    fi
  done

  echo ''

  if [ "$gWebUser" ]
  then
	webuser=$gWebUser
  else
  	if [ "$ARCH" = "hpux" ]; then
    		webuser='www'
	else
    		webuser='nobody'
  	fi
  fi

  if [ "$ARCH" = "hpux" ]; then
	echo 'Important Note'
	echo '--------------'
	echo 'On HP-UX you may not be able to use shared memory as nobody, and the suggested'
	echo 'workaround is to create a user www and use that user.'
	echo ' '
  fi

  echo 'Enter the name (or UID) of the user to run httpd as (Example: nobody)'
  $gEchoNL 'Default value is "'$webuser'": '
  SubEnter "$webuser" 'gWebUser'

  if [ "$gWebGroup" ]
  then
    webgroup=$gWebGroup
  else
  	if [ "$ARCH" = "hpux" ]; then
	    webgroup='users'
	else
	    webgroup='nogroup'
	fi
  fi

  echo 'Important Note'
  echo '--------------'
  echo 'Some kernels refuse to setgid(Group) or semctl(IPC_SET) when the value of'
  echo "(unsigned)Group is above 60000; don't use Group nogroup on these systems!"
  echo ' '

  echo 'Enter the name (or GID) of the group to run httpd as (Example: nogroup).'
  $gEchoNL 'Default value is "'$webgroup'": '
  SubEnter "$webgroup" 'gWebGroup'

  f_Title 'WEB SERVER CONFIGURATION'

  echo 'Summary for the Apache Web Server configuration:'
  echo ' '

  if [ $bSSL -eq 1 ]; then
  	echo '  The HTTPS protocol is:           enabled'
  	echo '  The SSL (https) port number is:  '$gSSLPortNum
  else
  	echo '  The HTTPS protocol is:            disabled'
  fi

  echo '  The Web server name is:          '$gHostName
  echo '  The http port number is:         '$gWebPortNum
  echo '  The httpd runs as user:          '$gWebUser
  echo '  The httpd runs as group:         '$gWebGroup
  echo ' '

  if SubContinueBackAbort '(C)ontinue, go (B)ack to make changes, or (A)bort (c/b/a)? [c] ' 0
  then
    gScreen=70
  else
    gScreen=10
  fi
}

#
# Operation - 70
#
##############
SubEmailID() {
##############
  if [ -z "`logname`" ]; then
	gusername=root
  else
	gusername=`logname`
  fi

  if [ "$gEmailID" ]
  then
    gemailid=$gEailID
  elif [ `domainname` ] && [ `domainname` != "(none)" ]; then  
    gemailid="$gusername@`domainname`"
  else
    gemailid=$gusername
  fi

  cont=0
  while [ $cont -eq 0 ]
  do
    f_Title 'ENTER WEB SERVER ADMINISTRATOR E-MAIL ADDRESS'

    echo 'Please specify a fully qualified email address (eg. joe@yourcompany.com) from'
    echo 'which scheduling and conditional alerts are sent.'

    if [ "$gEmailID" ]
    then
      $gEchoNL 'Default value is "'$gEmailID'": '
      SubEnter "$gEmailID" 'gEmailID'
    else
      $gEchoNL 'Default value is "'$gemailid'": '
      SubEnter "$gemailid" 'gEmailID'
    fi

    echo ' '

    if [ -z "$gEmailID" ]; then
      echo 'Please enter a valid E-mail id.'
      f_Pause
      continue
    fi

    if [ -z "`echo $gEmailID | grep  '^.*@.*\..*$'`" ]; then
      echo 'Please enter a valid E-mail id ion the form of <user>@<domain>.<domain extension>'
      f_Pause
    else
	cont=1
    fi
  done
  
  f_Title

  echo 'Summary of questioned responses:'
  echo ' '
  echo '  Your e-mail address is:'
  echo "    "$gEmailID
  echo ' '

  if SubContinueBackAbort '(C)ontinue, go (B)ack to make changes, or (A)bort (c/b/a)? [c] ' 0
  then
    gScreen=170
  else
    gScreen=70
  fi
}


#
# Operation - 170
#
################
SubReadyCopy() {
################
  f_Title 'READY TO COPY FILES'

  echo 'We are now ready to copy files to the destination. Choose "Continue"'
  echo 'to proceed.'
  echo ' '

  echo 'The Supplied Web Server (Apache 1.3.37) will be installed under:'
  echo '  '"$gReporterInstallLocation"'/apache'
  echo ' '

  if SubContinueAbort '(C)ontinue or (A)bort installation (c/a)? [c] ' 0
  then
    gScreen=180
  fi
  echo ' '
}


#
# Operation - 180
#
################
SubCopyFiles() {
################
  currentDir=`pwd`

  f_Title "EXTRACTING FILES"

  echo 'Installing Apache 1.3.37 with SSL Module 2.8.28 and Open SSL 0.9.8g...'
  cd $gReporterInstallLocation

  f_Spin

  cd $gReporterInstallLocation

  if [ "${ARCH}" = "solaris" ]; then
  	uncompress -cf $currentDir/apache/apache-1.3.37-${ARCH}${OS}.tar.Z | tar xmof -
  	ERR=$?
 elif [ "$ARCH" = "linux" ]; then
	uncompress -cf $currentDir/apache/apache-1.3.37-${ARCH}.tar.Z | tar --no-same-owner -xmf -
  	ERR=$
  else
  	uncompress -cf $currentDir/apache/apache-1.3.37-${ARCH}.tar.Z | tar xmof -
  	ERR=$?
  fi
  
  if [ $ERR -ne 0 ]; then
  	echo ' '
  	echo "ERROR: Unable to locate required component."
  	exit 1
  fi

  f_Title "UPDATING CONFIGURATION AND SCRIPT FILES..."

	 echo 'Updating ' "$gReporterInstallLocation/apache/conf/httpd.conf"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__INSTALL_PATH__" "$gReporterInstallLocation/apache"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__EMAIL_ADDR__" "$gEmailID"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "\#ServerName __SERVER_NAME__" "ServerName $gHostName"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__SERVER_NAME__" "$gHostName"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__SERVER_USER__" "$gWebUser"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__SERVER_GROUP__" "$gWebGroup"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__SERVER_PORT__" "$gPortNum"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__JRUN_PATH__" "$gJRUNPATH"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__PROXY_HOST__" "$gProxyHost"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf" "__PROXY_PORT__" "$gProxyPort"

	echo 'Updating ' "$gReporterInstallLocation/apache/conf/httpd.conf.default"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf.default" "__INSTALL_PATH__" "$gReporterInstallLocation/apache"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf.default" "__EMAIL_ADDR__" "$gEmailID"
	f_Replace "$gReporterInstallLocation/apache/conf/httpd.conf.default" "__SERVER_NAME__" "$gHostName"

	echo 'Updating ' "$gReporterInstallLocation/apache/bin/apachectl"
	f_Replace "$gReporterInstallLocation/apache/bin/apachectl" "__INSTALL_PATH__" "$gReporterInstallLocation/apache"

	echo 'Updating ' "$gReporterInstallLocation/apache/bin/apxs"
	f_Replace "$gReporterInstallLocation/apache/bin/apxs" "__INSTALL_PATH__" "$gReporterInstallLocation/apache"


  f_Pause

  gScreen=220
}

#
# Called from SubMain()
#
#########################
SubPostInstallMessage() {
#########################
  $NRCLEAR

  f_Title

  echo "Congratulations, you have finished installing Apache."
  echo ""
}


#
# Called from SubMain()
#
#####################
SubInstallOptions() {
#####################
  gScreen=20

  while [ "$gScreen" != 0 ]
  do
    case $gScreen in
    20)
	SubReporterDestination
	;;
    10)
  	SubSuppliedWebServer
	;;
    70)
	SubEmailID
	;;
    170)
	SubReadyCopy
	;;
    180)
    	SubCopyFiles
	;;
    220)
	gScreen=0
	;;
    esac
  done
}


###########
SubMain() {
###########
  SubInit
  f_GetOS
  f_GetPorts
  SubWelcome
  SubInstallOptions
  SubPostInstallMessage
}


SubMain
exit 0
